* Syntax  | lcList = ez_drlst()
* Action  | Return list of drives (DOS or Windows) or volumes (Mac).
* Process | lcList     List of available disk drives/volumes.
*         |            DOS or Windows:  "ABCF"
*         |            Mac:             "MacDisk;ADLAN_1.SYS"
*         |                             Delimited by semicolons.
*         |            UNIX:            Null string
* Note  1 | To make this work for DOS, C:\CONFIG.SYS must have
*         | SHELL=c:\command.com /e:512 /p /f
*         | REM   /e:  Environment size  (your needs will vary)
*         | REM   /p:  Permanent (needed, to run AUTOEXEC.BAT)
*         | REM   /f:  Fail automatically  (undocumented)
*         | REM        Avoids "Abort, Retry, Fail" message.
*         | The remark lines are necessary to keep some well-
*         | meaning person from removing these lines.
*         |
*         | Remember to reboot after adding these lines, to
*         | CONFIG.SYS, in order to activate them.
*         |
*       2 | To make this work for Windows, FOXTOOLS.FLL must be
*         | available in the FoxPro startup directory.
*         | 
*         | I hated to give in and use the unsupported functions
*         | in FoxTools, but I could not find a way to trap the
*         | drive-not-ready error in Windows.
*         | 
*       3 | To make this work for Macintosh, FOXTOOLS.MLB must
*         | be available in System Folder:Extensions, or in the
*         | current folder.
*         | 
*       4 | Just because a disk drive is available does not mean
*         | that it's ready.  For example, drive A: might not
*         | have a formatted diskette in it.
*         | 
* Author  | Jack Hairston, 73071.1762@compuserve.com
* History | 09-01-95  jeh  New procedure
*--

lclist = []                            && default to null string

DO CASE
CASE _DOS
  *-- Save environment for cleanup
  IF SET( "talk" ) = "ON"              && don't show this
    SET TALK OFF
    lcoldtalk = "ON"
  ELSE
    lcoldtalk = "OFF"
  ENDIF

  lcolderror = ON( 'error' )           && save for cleanup
  lcolddefa = SYS( 5 ) + CURDIR()      && save for restore
  ON ERROR llret = .F.

  *-- Check all possible disk drives.
  FOR lni = 65 TO 90                   && "A" to "Z"
    llret = .T.                        && assume success
    SET DEFAULT TO ( CHR( m.lni ) + ":" ) && set llret if no directory
    IF m.llret
      lclist = m.lclist + CHR( m.lni )
    ENDIF
  ENDFOR

  *-- Clean up
  SET DEFAULT TO ( m.lcolddefa )       && restore original directory
  IF EMPTY( m.lcolderror)              && restore error handler
    ON ERROR                           && no error handler, as before
  ELSE
    ON ERROR &lcolderror               && note absence of "m."
  ENDIF
  IF m.lcoldtalk = "ON"
    SET TALK ON
  ENDIF
  

CASE _WINDOWS
  *-- Make sure FoxTools library is loaded.
  IF ! "FOXTOOLS" $ SET( "LIBRARY" )
    SET LIBRARY TO ( SYS( 2004 ) + "FOXTOOLS" ) ADDITIVE
  ENDIF

  IF "FOXTOOLS" $ SET( "LIBRARY" )     && library is loaded
    FOR lni = 65 TO 90                 && "A" to "Z"
      lcdrive = CHR( m.lni ) + ":"     && drive to check
      lndrivetype = DRIVETYPE( m.lcdrive )
      *-- DRIVETYPE() returns
      *-- 0   No type--error
      *-- 2   Floppy drive
      *-- 3   Hard drive
      *-- 4   Removable- or network drive
      IF m.lndrivetype > 1 AND m.lndrivetype < 5
        lclist = m.lclist + CHR( m.lni )   && add drive to list
      ENDIF
    ENDFOR
  ELSE
    WAIT WINDOW NOWAIT ;
      "EZ_DRLST could not load FoxTools"
  ENDIF
  
CASE _MAC
  *-- Make sure FoxTools library is loaded.
  IF ! "FOXTOOLS" $ SET( "LIBRARY" )
    SET LIBRARY TO FOXTOOLS ADDITIVE
  ENDIF

  IF "FOXTOOLS" $ SET( "LIBRARY" )     && library is loaded
    lclist = FxVolume()                && get volume list
    IF TYPE( "m.lclist" ) != "C"       && numeric if error
      lclist = []                      && back to null string
      WAIT WINDOW NOWAIT ;
        "EZ_DRLST could not get volumes"
    ENDIF
  ELSE
    WAIT WINDOW NOWAIT ;
      "EZ_DRLST could not load FoxTools"
  ENDIF
ENDCASE

RETURN m.lclist
*:  EOF() ez_drlst.prg
